@@ -1,5 +1,5 @@
 /*
- *	$Id: cdeclient.cpp,v 1.24 2004/07/23 23:13:01 montanaro Exp $
+ *	$Id: cdeclient.cpp,v 1.26 2005/01/07 11:14:24 mlaurent Exp $
  *
  *	CDE KWin client - emulates the look and feel
  *	of dtwm, the CDE window manager.
@@ -30,7 +30,7 @@
 #include <klocale.h>
 #include <kconfig.h>
 
-extern "C" KDecorationFactory* create_factory()
+extern "C" KDE_EXPORT KDecorationFactory* create_factory()
 {
     return new CDE::CdeClientFactory();
 }
@@ -231,6 +231,23 @@ bool CdeClientFactory::reset(unsigned long /*changed*/)
     return true;
 }
 
+bool CdeClientFactory::supports( Ability ability )
+{
+    switch( ability )
+    {
+        case AbilityAnnounceButtons:
+        case AbilityButtonMenu:
+        case AbilityButtonOnAllDesktops:
+        case AbilityButtonHelp:
+        case AbilityButtonMinimize:
+        case AbilityButtonMaximize:
+        case AbilityButtonClose:
+            return true;
+        default:
+            return false;
+    };
+}
+
 QValueList< CdeClientFactory::BorderSize >
 CdeClientFactory::borderSizes() const
 {
