@@ -26,7 +26,7 @@
 #include <klocale.h>
 #include <kpixmapeffect.h>
 #include <kpixmap.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <qlabel.h>
 #include "resources.h"
 #include "glowclient.h"
@@ -167,7 +167,7 @@ void GlowClientGlobals::readTheme()
 	QString theme_config_file = KGlobal::dirs()->findResource ("data",
 			QString("kwin/glow-themes/") + config()->themeName + "/" +
 			config()->themeName + ".theme");
-	if (theme_config_file == QString::null)
+	if (theme_config_file.isNull())
 	{
 		config()->themeName = "default";
 		return;
@@ -232,6 +232,23 @@ bool GlowClientGlobals::reset( unsigned long changed )
 	return true; // FRAME
 }
 
+bool GlowClientGlobals::supports( Ability ability )
+{
+    switch( ability )
+    {
+        case AbilityAnnounceButtons:
+        case AbilityButtonOnAllDesktops:
+        case AbilityButtonSpacer:
+        case AbilityButtonHelp:
+        case AbilityButtonMinimize:
+        case AbilityButtonMaximize:
+        case AbilityButtonClose:
+            return true;
+        default:
+            return false;
+    };
+}
+
 bool GlowClientGlobals::createPixmaps()
 {
 	for( int type=0; type<=Close; type++ ) {
@@ -680,7 +697,7 @@ void GlowClient::resetLayout()
 	midLayout->addSpacing(SIDE_MARGIN);
 	if(isPreview())
 		midLayout->addWidget(
-				new QLabel( i18n( "<b><center>Glow</center></b>" ), widget()));
+				new QLabel( i18n( "<b><center>Glow preview</center></b>" ), widget()));
 	else
 		midLayout->addItem( new QSpacerItem( 0, 0 ));
 	midLayout->addSpacing(SIDE_MARGIN);
@@ -855,7 +872,7 @@ KDecoration* GlowClientGlobals::createDecoration( KDecorationBridge* bridge )
 } // end of namespace
 
 extern "C"
-KDecorationFactory* create_factory()
+KDE_EXPORT KDecorationFactory* create_factory()
 {
 	return Glow::GlowClientGlobals::instance();
 }
