@@ -1,5 +1,5 @@
 /*
-  $Id: icewm.cpp,v 1.42.2.1 2004/11/25 16:09:56 lunakl Exp $
+  $Id: icewm.cpp,v 1.47 2005/01/07 11:14:24 mlaurent Exp $
 
   Gallium-IceWM themeable KWin client
 
@@ -589,7 +589,7 @@ void ThemeHandler::setPixmapButton( QPixmap* p[], QString s1, QString s2)
 
 	QString str = locate("appdata", QString("icewm-themes/")
 				+ themeName + s1 + "A" + s2);
-	if (str == QString::null)
+	if (str.isEmpty())
 		str = locate("appdata", QString("icewm-themes/")
 				+ themeName + s1 + s2);
 
@@ -633,7 +633,7 @@ void ThemeHandler::setPixmapButton( QPixmap* p[], QString s1, QString s2)
 
 	str = locate("appdata", QString("icewm-themes/")
 		     + themeName + s1 + "I" + s2);
-	if (str == QString::null)
+	if (str.isEmpty())
 		str = locate("appdata", QString("icewm-themes/")
 			     + themeName + s1 + s2);
 
@@ -740,6 +740,21 @@ bool ThemeHandler::reset( unsigned long)
 	return true;
 }
 
+bool ThemeHandler::supports( Ability ability )
+{
+    switch( ability )
+    {
+        case AbilityAnnounceButtons:
+        case AbilityButtonMenu:
+        case AbilityButtonOnAllDesktops:
+        case AbilityButtonMinimize:
+        case AbilityButtonMaximize:
+        case AbilityButtonClose:
+            return true;
+        default:
+            return false;
+    };
+}
 
 
 ////////////////////////////////////////////////////////////////////////////////////////////
@@ -885,7 +900,7 @@ void IceWMClient::init()
 	// Do something IceWM can't do :)
 	if (titleBarOnTop) {
         	if( isPreview())
-			grid->addWidget( new QLabel( i18n( "<center><b>IceWM</b></center>" ), widget() ), 2, 1);
+			grid->addWidget( new QLabel( i18n( "<center><b>IceWM preview</b></center>" ), widget() ), 2, 1);
                 else
 			grid->addItem( new QSpacerItem( 0, 0 ), 2, 1);
 		// no shade flicker
@@ -895,7 +910,7 @@ void IceWMClient::init()
 		// no shade flicker
     	grid->addItem( new QSpacerItem( 0, 0, QSizePolicy::Fixed,									   QSizePolicy::Expanding ) );
         	if( isPreview())
-			grid->addWidget( new QLabel( i18n( "<center><b>IceWM</b></center>" ), widget() ), 1, 1);
+			grid->addWidget( new QLabel( i18n( "<center><b>IceWM preview</b></center>" ), widget() ), 1, 1);
                 else
 			grid->addItem( new QSpacerItem( 0, 0 ), 1, 1);
     }
@@ -1663,7 +1678,7 @@ bool IceWMClient::eventFilter( QObject* o, QEvent* e )
 
 extern "C"
 {
-	KDecorationFactory *create_factory()
+	KDE_EXPORT KDecorationFactory *create_factory()
 	{
 		IceWM::clientHandler = new IceWM::ThemeHandler;
 		return IceWM::clientHandler;
