@@ -423,7 +423,7 @@ void NextClient::init()
 
 /**
    Preconditions:
-       + this->button is an array of length MAX_NUM_BUTTONS
+       + button is an array of length MAX_NUM_BUTTONS
 
    Postconditions:
        + Title bar and buttons have been initialized and laid out
@@ -936,6 +936,27 @@ bool NextClientFactory::reset(unsigned long /*changed*/)
     return true;
 }
 
+bool NextClientFactory::supports( Ability ability )
+{
+    switch( ability )
+    {
+        case AbilityAnnounceButtons:
+        case AbilityButtonMenu:
+        case AbilityButtonOnAllDesktops:
+        case AbilityButtonHelp:
+        case AbilityButtonMinimize:
+        case AbilityButtonMaximize:
+        case AbilityButtonClose:
+        case AbilityButtonAboveOthers:
+        case AbilityButtonBelowOthers:
+        case AbilityButtonShade:
+        case AbilityButtonResize:
+            return true;
+        default:
+            return false;
+    };
+}
+
 QValueList< NextClientFactory::BorderSize >
 NextClientFactory::borderSizes() const
 {
@@ -947,7 +968,7 @@ NextClientFactory::borderSizes() const
 
 } // KStep namespace
 
-extern "C" KDecorationFactory* create_factory()
+extern "C" KDE_EXPORT KDecorationFactory* create_factory()
 {
     return new KStep::NextClientFactory();
 }
